@@ -169,13 +169,7 @@ namespace gnote {
       note_path = override_path;
     }
     if(note_path.empty()) {
-      note_path = Gnote::conf_dir();
-    }
-    std::string home_dir;
-    const char *s = getenv("HOME");
-    if(s) {
-      home_dir = s;
-      note_path = sharp::string_replace_first(note_path, "~", home_dir);
+      note_path = Gnote::data_dir();
     }
 
     return note_path;
@@ -330,6 +324,7 @@ namespace gnote {
   void Gnote::on_show_about_action()
   {
     std::list<Glib::ustring> authors;
+    authors.push_back("Debarshi Ray <debarshir@src.gnome.org>");
     authors.push_back("Hubert Figuiere <hub@figuiere.net>");
     authors.push_back(_("and Tomboy original authors."));
     
@@ -348,7 +343,8 @@ namespace gnote {
     about.set_name("Gnote");
     about.set_version(VERSION);
     about.set_logo(utils::get_icon("gnote", 48));
-    about.set_copyright(_("Copyright \xc2\xa9 2009 Hubert Figuiere\n"
+    about.set_copyright(_("Copyright \xc2\xa9 2009 Debarshi Ray\n"
+                          "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                           "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
     about.set_comments(_("A simple and easy to use desktop "
                          "note-taking application."));
@@ -388,15 +384,32 @@ namespace gnote {
   }
 
 
+  std::string Gnote::cache_dir()
+  {
+    return Glib::get_user_cache_dir() + "/gnote";
+  }
+
+
   std::string Gnote::conf_dir()
   {
-    std::string dir;
-    const char * home = getenv("HOME");
-    if(!home) {
-      home = ".";
-    }
-    dir = std::string(home) + "/.gnote";
-    return dir;
+    return Glib::get_user_config_dir() + "/gnote";
+  }
+
+
+  std::string Gnote::data_dir()
+  {
+    return Glib::get_user_data_dir() + "/gnote";
+  }
+
+
+  std::string Gnote::old_note_dir()
+  {
+    std::string home_dir = Glib::get_home_dir();
+
+    if (home_dir.empty())
+      home_dir = Glib::get_current_dir();
+
+    return home_dir + "/.gnote";
   }
 
 
