@@ -23,6 +23,7 @@
 #include <boost/algorithm/string/finder.hpp>
 
 #include <glibmm/i18n.h>
+#include <gtkmm/arrow.h>
 #include <gtkmm/image.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/separatortoolitem.h>
@@ -170,13 +171,8 @@ namespace gnote {
                                      GDK_N, Gdk::CONTROL_MASK,
                                      Gtk::ACCEL_VISIBLE);
 
-    // Have Esc key close the note window
-    if (Preferences::obj().get<bool>(Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE))
-      m_keypress_cid  = signal_key_press_event().connect(sigc::mem_fun(*this, &NoteWindow::on_key_pressed));
+    signal_key_press_event().connect(sigc::mem_fun(*this, &NoteWindow::on_key_pressed));
 
-    // Watch the escape setting in GConf
-    m_gconf_notify = Preferences::obj().add_notify(Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE,
-                   &NoteWindow::on_escape_setting_changed, this);
 
     // Increase Indent
     m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::change_depth_right_handler),
@@ -221,29 +217,17 @@ namespace gnote {
     move(x, y);
   }
 
-  void NoteWindow::on_escape_setting_changed(GConfClient *, guint /*cnxid*/, 
-                                             GConfEntry* entry, gpointer data)
-  {
-    NoteWindow * self = static_cast<NoteWindow*>(data);
-
-    GConfValue * value = gconf_entry_get_value(entry);
-    if(!value) {
-      return;
-    }
-
-    if(gconf_value_get_bool(value)) {
-      self->m_keypress_cid  = self->signal_key_press_event().connect(
-        sigc::mem_fun(*self, &NoteWindow::on_key_pressed));
-    }
-    else {
-      self->m_keypress_cid.disconnect();
-    }
-  }
 
   bool NoteWindow::on_key_pressed(GdkEventKey *ev)
   {
     if(ev->keyval == GDK_Escape) {
-      close_window_handler();
+      if (m_find_bar && m_find_bar->is_visible()) {
+        m_find_bar->hide();
+      }
+      else if (Preferences::obj().get<bool>(
+                 Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE)) {
+        close_window_handler();
+      }
       return true;
     }
     return false;
@@ -637,7 +621,7 @@ namespace gnote {
   NoteFindBar::NoteFindBar(Note & note)
     : Gtk::HBox(false, 0)
     , m_note(note)
-    , m_next_button(_("Find _Next"))
+    , m_next_button(_("_Next"))
     , m_prev_button(_("_Previous"))
     , m_entry_changed_timeout(NULL)
     , m_note_changed_timeout(NULL)
@@ -659,9 +643,10 @@ namespace gnote {
     m_entry.signal_changed().connect(sigc::mem_fun(*this, &NoteFindBar::on_find_entry_changed));
     m_entry.signal_activate().connect(sigc::mem_fun(*this, &NoteFindBar::on_find_entry_activated));
     m_entry.show();
-    pack_start(m_entry, false, false, 0);
+    pack_start(m_entry, true, true, 0);
 
-    m_prev_button.set_image(*manage(new Gtk::Image (Gtk::Stock::GO_BACK, Gtk::ICON_SIZE_MENU)));
+    m_prev_button.set_image(*manage(new Gtk::Arrow (Gtk::ARROW_LEFT, 
+                                                    Gtk::SHADOW_NONE)));
     m_prev_button.set_relief(Gtk::RELIEF_NONE);
     m_prev_button.set_sensitive(false);
     m_prev_button.set_focus_on_click(false);
@@ -669,7 +654,8 @@ namespace gnote {
     m_prev_button.show();
     pack_start(m_prev_button, false, false, 0);
 
-    m_next_button.set_image(*manage(new Gtk::Image (Gtk::Stock::GO_FORWARD, Gtk::ICON_SIZE_MENU)));
+    m_next_button.set_image(*manage(new Gtk::Arrow (Gtk::ARROW_RIGHT, 
+                                                    Gtk::SHADOW_NONE)));
     m_next_button.set_relief(Gtk::RELIEF_NONE);
     m_next_button.set_sensitive(false);
     m_next_button.set_focus_on_click(false);
@@ -1106,6 +1092,8 @@ namespace gnote {
     , m_bullets(_("Bullets"))
     , m_increase_indent(Gtk::Stock::INDENT)
     , m_decrease_indent(Gtk::Stock::UNINDENT)
+    , m_increase_font(_("Increase Font Size"), true)
+    , m_decrease_font(_("Decrease Font Size"), true)
     {
       m_undo = manage(new Gtk::ImageMenuItem (Gtk::Stock::UNDO));
 //      m_undo->set_accel_group(accel_group);
@@ -1201,6 +1189,22 @@ namespace gnote {
 
       m_hidden_no_size.hide();
 
+      m_increase_font.add_accelerator ("activate",
+                                       accel_group,
+                                       GDK_plus,
+                                       Gdk::CONTROL_MASK,
+                                       Gtk::ACCEL_VISIBLE);
+      m_increase_font.signal_activate()
+        .connect(sigc::mem_fun(*this, &NoteTextMenu::increase_font_clicked));
+
+      m_decrease_font.add_accelerator ("activate",
+                                       accel_group,
+                                       GDK_minus,
+                                       Gdk::CONTROL_MASK,
+                                       Gtk::ACCEL_VISIBLE);
+      m_decrease_font.signal_activate()
+        .connect(sigc::mem_fun(*this, &NoteTextMenu::decrease_font_clicked));
+
       Gtk::SeparatorMenuItem *spacer2 = manage(new Gtk::SeparatorMenuItem());
 
       m_bullets_clicked_cid = m_bullets.signal_activate()
@@ -1236,6 +1240,8 @@ namespace gnote {
       append(m_normal);
       append(m_large);
       append(m_huge);
+      append(m_increase_font);
+      append(m_decrease_font);
       append(*spacer2);
       append(m_bullets);
       append(m_increase_indent);
@@ -1358,6 +1364,48 @@ namespace gnote {
       m_buffer->set_active_tag(tag);
   }
 
+  void NoteTextMenu::increase_font_clicked ()
+  {
+    if (m_event_freeze)
+      return;
+
+    if (m_buffer->is_active_tag ("size:small")) {
+      m_buffer->remove_active_tag ("size:small");
+    } 
+    else if (m_buffer->is_active_tag ("size:large")) {
+      m_buffer->remove_active_tag ("size:large");
+      m_buffer->set_active_tag ("size:huge");
+    } 
+    else if (m_buffer->is_active_tag ("size:huge")) {
+      // Maximum font size, do nothing
+    } 
+    else {
+      // Current font size is normal
+      m_buffer->set_active_tag ("size:large");
+    }
+ }
+
+  void NoteTextMenu::decrease_font_clicked ()
+  {
+    if (m_event_freeze)
+      return;
+
+    if (m_buffer->is_active_tag ("size:small")) {
+// Minimum font size, do nothing
+    } 
+    else if (m_buffer->is_active_tag ("size:large")) {
+      m_buffer->remove_active_tag ("size:large");
+    } 
+    else if (m_buffer->is_active_tag ("size:huge")) {
+      m_buffer->remove_active_tag ("size:huge");
+      m_buffer->set_active_tag ("size:large");
+    } 
+    else {
+// Current font size is normal
+      m_buffer->set_active_tag ("size:small");
+    }
+  }
+
   void NoteTextMenu::undo_clicked ()
   {
     if (m_undo_manager.get_can_undo()) {
